#!/bin/sh

# Author: ghostbunny
# Version: 1.4
# Date: 13.11.2012
# Licence: GPL V.2 (or at your choice any higher version)
# Description: This script tries to fix xorg file 50-synaptics.conf for 
#              some touchpads which lose the tap and scroll functionality

####################### ChangeLog #######################
# 24.09.2012_23:09 ghostbunny				#
# - added changelog					#
# - added test for existence of the config file and	#
#   directory						#
# - added exit in if conditions to decrease runtime	#
# - code clean up					#
#							#
# 25.09.2012_10:23 ghostbunny				#
# - fixed test for config file and config directory	#
#   50-synaptics.conf is a file no directory		#
# - added exit status descripton			#
#							#
# 25.09.2012_22:10 ghostbunny				#
# - replaced directing echo output to file by cat	#
# - replaced #Fixed by ghostbunny patch by just #Fixed	#
#							#
# 02.10.2012_00:21 ghostbunny				#
# - implemented solution 5				#
# - removed else branch from the if condition		#
#   which starts in line 53				#
# - remove never used if clause from inside the if 	#
#   which starts in line 53 (test whether the file 	#
#   contains the string #Fixed but we have already done #
#   this						#
# - change the date :P					#
#							#
# 05.11.2012_18:06 ghostbunny				#
# - removed -i option for grep in elantech branch	#
# - fixed description for solution 5			#
# 							#
# 06.11.2012_21:03 ghostbunny				#
# - removed wrong " after EndSection in elantech cat	#
#   section						#
#							#
# 07.11.2012_16:49 ghostbunny				#
# - added detection of alps dualpoint device it uses	#
#   solution two like some synaptics touchpads		#
# - bumped version and date				#
#							#
# 13.11.2012_22:23 ghostbunny				#
# - removed #Fixed from cat parts 			#
# - removed if condition for check of #fixed		#
#							#
# 24.02.2013_22:33 ghostbunny				#
# - fixed to many " for LeftEdge/RightEdge in Fix 3	#




################# Exit staus description ################
# 0 found a matching touchpad and sets the config file	#
# 1 no matching touchpad found just added a short 	#
#   comment to prevent rerun on every startup		#
#########################################################

# Test existence of config file and folder
if [ ! -d /etc/X11/xorg.conf.d ]; then

	mkdir -p /etc/X11/xorg.conf.d

	if [ ! -f /etc/X11/xorg.conf.d/50-synaptics.conf ]; then
	
		touch /etc/X11/xorg.conf.d/50-synaptics.conf
	fi
fi 



# Fix 3 for ALPS GlidePoint Touchpads
if [ $(dmesg | grep -c "input: AlpsPS/2 ALPS GlidePoint") -eq 1 ]; then
		
	cat > /etc/X11/xorg.conf.d/50-synaptics.conf << EOF
Section "InputClass"
    Identifier "touchpad catchall"
    Driver "synaptics"
    MatchIsTouchpad "on"
    MatchDevicePath "/dev/input/event*" 
    Option  "Protocol"      "auto-dev" 
    Option  "LeftEdge"      "120" 
    Option  "RightEdge"     "830" 
    Option  "TopEdge"       "120" 
    Option  "BottomEdge"    "650" 
    Option  "FingerLow"     "25" 
    Option  "FingerHigh"    "30" 
    Option  "MaxTapTime"    "180" 
    Option  "MaxTapMove"    "220" 
    Option  "VertScrollDelta" "100" 
    Option  "MinSpeed"      "0.20" 
    Option  "MaxSpeed"      "1.00" 
    Option  "AccelFactor" "0.15" 
    Option  "SHMConfig"     "1" 
    Option  "VertTwoFingerScroll"   "1" 
    Option  "HorizTwoFingerScroll"  "1" 
    Option  "VertEdgeScroll"        "1" 
    Option  "HorizEdgeScroll"       "1" 
    Option  "TapButton1"            "1" 
    Option  "TapButton2"            "2" 
    Option  "TapButton3"            "3" 
EndSection
EOF
	exit 0
fi
	
# Fix 2 for Synaptics Touchpad and Alps DualPoint
if [ $(dmesg | grep -c "Synaptics Touchpad, model: 1, fw: 6.3") -eq 1 ] || [ $(dmesg | grep -c "input: AlpsPS/2 ALPS DualPoint TouchPad") -eq 1 ]; then
		
	cat > /etc/X11/xorg.conf.d/50-synaptics.conf << EOF
Section "InputClass" 
    Identifier "touchpad catchall" 
    Driver "synaptics" 
    MatchIsTouchpad "on" 
    MatchDevicePath "/dev/input/event*" 
    #Option  "Device"	"/dev/input/mouse0" 
    Option  "Protocol"      "auto-dev" 
    Option  "LeftEdge"      "1700" 
    Option  "RightEdge"     "5300" 
    Option  "TopEdge"       "1700" 
    Option  "BottomEdge"    "4200" 
    Option  "FingerLow"     "25" 
    Option  "FingerHigh"    "30" 
    Option  "MaxTapTime"    "180" 
    Option  "MaxTapMove"    "220" 
    Option  "VertScrollDelta" "100" 
    Option  "MinSpeed"      "0.20" 
    Option  "MaxSpeed"      "1.00" 
    Option  "AccelFactor" "0.15" 
    Option  "SHMConfig"     "1" 
    Option  "VertTwoFingerScroll"   "1" 
    Option  "HorizTwoFingerScroll"  "1" 
    Option  "VertEdgeScroll"        "1" 
    Option  "HorizEdgeScroll"       "1" 
    Option  "TapButton1"            "1" 
    Option  "TapButton2"            "2" 
    Option  "TapButton3"            "3" 
EndSection 
EOF
	exit 0
fi

	
# Fix 4 for Elantech Touchpads
if [ $(dmesg | grep -c "input: ETPS/2 Elantech Touchpad") -eq 1 ]; then
		
		cat > /etc/X11/xorg.conf.d/50-synaptics.conf << EOF
Section "InputClass" 
    Identifier "touchpad catchall" 
    Driver "synaptics" 
    MatchIsTouchpad "on" 
    MatchDevicePath "/dev/input/event*" 
    #Option "Device" "/dev/input/mouse0" 
    Option  "Protocol"      "auto-dev" 
    #Option  "LeftEdge"      "120" 
    #Option  "RightEdge"     "830" 
    #Option  "TopEdge"       "120" 
    #Option  "BottomEdge"    "650" 
    Option  "FingerLow"     "25" 
    Option  "FingerHigh"    "30" 
    Option  "MaxTapTime"    "180" 
    Option  "MaxTapMove"    "220" 
    Option  "VertScrollDelta" "100" 
    Option  "MinSpeed"      "0.20" 
    Option  "MaxSpeed"      "1.00" 
    Option  "AccelFactor" "0.15" 
    Option  "SHMConfig"     "1" 
    Option  "VertTwoFingerScroll"   "1" 
    Option  "HorizTwoFingerScroll"  "1" 
    Option  "VertEdgeScroll"        "1" 
    Option  "HorizEdgeScroll"       "1"       	
    Option  "TapButton1"            "1" 
    Option  "TapButton2"            "2" 
    Option  "TapButton3"            "3" 
EndSection
EOF
	exit 0
fi

	
# Fix 5 for Acer Netbook (Aspire One 150 ZG5)
# Seems like this is also for a synaptics touchpad but needs a different
# configuration.
# IMPORTANT: DON'T MOVE THIS IN FRONT OF SOLUTION 2!!!
if [ $(dmesg | grep -c "input: SynPS/2 Synaptics TouchPad as") -eq 1 ]; then
		
	cat > /etc/X11/xorg.conf.d/50-synaptics.conf << EOF
Section "InputClass" 
    Identifier "touchpad catchall" 
    Driver "synaptics" 
    MatchIsTouchpad "on" 
    Option  "VertEdgeScroll"        "1" 
    Option  "TapButton1"            "1" 
EndSection 
EOF
	exit 0
fi

# we did not found a matching solution
exit 1
